function[w,tw]= adrienne(ejex,seg)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% VENTANA TEMPORAL DE ADRIENNE.
    %
    % function [w,tw]= adrienne(ejex,seg)
    %
    % DATOS DE ENTRADA:
    %   ejex: Eje x con todas las muestras temporales que tendr la
    %         seal MLS en segundos.
    %   seg: Duracin de la ventana temporal de adrienne en milisegundos,
    %        normalmente ser 7,9ms pero en ocasiones deber modificarse.
    %
    % DATOS DE SALIDA:
    %   w: Ventana creada.
    %   tw: Eje temporal correspondiente a la ventana.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

seg_plana=(seg-0.5)/10*7; % Duracin de la parte plana de la ventana
% de Adrienne segn la duracin total de la ventana insertada.
% La duracin de la primera parte siempre ser igual: 0.5ms.
% La duracin de las partes plana y derecha siempre llevarn una
% proporcin de 7/3.
                            
pointsi=0;   % Inicializamos el contador para saber el nmero de puntos
pointsm=0;   % con que tenemos que crear la parte izquierda y derecha de
pointsd=0;   % la ventana de Blackman-Harris.

for i=1:length(ejex)          % Hacemos el bucle para saber el nmero de 
    if ejex(i)<=0.5           % muestras que tiene que tener la ventana  
        pointsi=pointsi+1;    % segn la seal a utilizar y las 
    elseif ejex(i)<=seg_plana % restricciones de duracin de cada una de
        pointsm=pointsm+1;    % las partes.
    elseif ejex(i)<=seg
        pointsd=pointsd+1;
    end                     
end

wizq=blackmanharris(pointsi*2)'; % Creamos la ventana con el n de puntos
wder=blackmanharris(pointsd*2)'; % doble del que necesitamos en cada
                                 % parte, ya que nos crear la ventana 
                                 % entera y nosotros solo queremos media.

pizq=wizq(1,1:pointsi);          % Cada una de las partes creadas.
pmed=ones(1,pointsm);
pder=wder(1,(pointsd+1):(pointsd*2));

w=[pizq,pmed,pder];              % Ventana final.
tw=ejex((1:(length(w))));        % Eje temporal de la ventana.