function[X]=aislamiento(tw,dbmax)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funcin que realiza todos los parmetros intermedios para obtener el
% SI que clasifique pantallas acsticas segun la norma EN 1793-5.
%
%  function[X]=aislamiento(tw,dbmax)
%
%     DATOS DE ENTRADA:
%          tw: Tamao de la ventana temporal de Adrienne a utilizar (ms).
%          dbmax: Nivel mximo de seal obtenido (dB).
%
%     DATOS INTERMEDIOS:
%          Figuras 1 y 2. Respuestas impulsivas sobre ventana de Adrienne.
%          Figuras 3. Componentes directa y transmitidas en el tiempo.
%          Figuras 4. Componentes directa y transmitidas en frec.(1/3).
%
%     DATOS DE SALIDA:
%          X. Componentes directa y transmitida en 1/3 de octava puestas
%             en columnas (directa,5,1,2,etc).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Eje de tiempos de la seal MLS, milisegundos a los que se reproduce
% cada muestra y duracin de la seal.
load ejex;ejex=ejex';

% Respuestas impulsionales medidas, en filas.
load CL;factor=dbmax/max(abs(CL));CL=factor*CL;CL=abs(CL)';
load rimp5;rimp5=factor*rimp5;rimp5=abs(rimp5)';
load rimp1;rimp1=factor*rimp1;rimp1=abs(rimp1)';
load rimp2;rimp2=factor*rimp2;rimp2=abs(rimp2)';
load rimp3;rimp3=factor*rimp3;rimp3=abs(rimp3)';
load rimp4;rimp4=factor*rimp4;rimp4=abs(rimp4)';
load rimp6;rimp6=factor*rimp6;rimp6=abs(rimp6)';
load rimp7;rimp7=factor*rimp7;rimp7=abs(rimp7)';
load rimp8;rimp8=factor*rimp8;rimp8=abs(rimp8)';
load rimp9;rimp9=factor*rimp9;rimp9=abs(rimp9)';

% Creo la ventana de Adrienne necesaria para el enventanado.
[w]= adrienne(ejex,tw); 

% Enventano cada una de las seales medidas.
[xeCL,weCL]=enventanado(CL,w,ejex);[xe5,we5]=enventanado(rimp5,w,ejex);
[xe1,we1]=enventanado(rimp1,w,ejex);[xe2,we2]=enventanado(rimp2,w,ejex);
[xe3,we3]=enventanado(rimp3,w,ejex);[xe4,we4]=enventanado(rimp4,w,ejex);
[xe6,we6]=enventanado(rimp6,w,ejex);[xe7,we7]=enventanado(rimp7,w,ejex);
[xe8,we8]=enventanado(rimp8,w,ejex);[xe9,we9]=enventanado(rimp9,w,ejex);

% Representacin de la ventana de Adrienne sobre las seales para
% comprobar la largura de esta.
figure
subplot(3,2,1);plot(ejex,CL);title('Campo libre')
hold on;subplot(3,2,1);plot(ejex,weCL*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,2);plot(ejex,rimp5);title('5')
hold on;subplot(3,2,2);plot(ejex,we5,'r--');xlabel('Tiempo(ms)');
subplot(3,2,3);plot(ejex,rimp1);title('1')
hold on;subplot(3,2,3);plot(ejex,we1,'r--');xlabel('Tiempo(ms)');
subplot(3,2,4);plot(ejex,rimp2);title('2')
hold on;subplot(3,2,4);plot(ejex,we2,'r--');xlabel('Tiempo(ms)');
subplot(3,2,5);plot(ejex,rimp3);title('3')
hold on;subplot(3,2,5);plot(ejex,we3,'r--');xlabel('Tiempo(ms)');
figure
subplot(3,2,1);plot(ejex,rimp4);title('4')
hold on;subplot(3,2,1);plot(ejex,we4,'r--');xlabel('Tiempo(ms)');
subplot(3,2,2);plot(ejex,rimp6);title('6')
hold on;subplot(3,2,2);plot(ejex,we6,'r--');xlabel('Tiempo(ms)');
subplot(3,2,3);plot(ejex,rimp7);title('7')
hold on;subplot(3,2,3);plot(ejex,we7,'r--');xlabel('Tiempo(ms)');
subplot(3,2,4);plot(ejex,rimp8);title('8')
hold on;subplot(3,2,4);plot(ejex,we8,'r--');xlabel('Tiempo(ms)');
subplot(3,2,5);plot(ejex,rimp9);title('9')
hold on;subplot(3,2,5);plot(ejex,we9,'r--');xlabel('Tiempo(ms)');

% Representacin de las seales enventanadas.
figure
subplot(5,2,1);plot(ejex,xeCL);title('Campo libre')
subplot(5,2,2);plot(ejex,xe5);title('5')
subplot(5,2,3);plot(ejex,xe1);title('1')
subplot(5,2,4);plot(ejex,xe2);title('2')
subplot(5,2,5);plot(ejex,xe3);title('3')
subplot(5,2,6);plot(ejex,xe4);title('4')
subplot(5,2,7);plot(ejex,xe6);title('6')
subplot(5,2,8);plot(ejex,xe7);title('7')
subplot(5,2,9);plot(ejex,xe8);title('8')
subplot(5,2,10);plot(ejex,xe9);title('9')

% Espectro de potencia de cada una de las componentes.
[Xd,F]=filtbank(CL*max(abs(CL)/dbmax),25641);
[Xt5]=filtbank(xe5*max(abs(CL)/dbmax),25641);
[Xt1]=filtbank(xe1*max(abs(CL)/dbmax),25641);
[Xt2]=filtbank(xe2*max(abs(CL)/dbmax),25641);
[Xt3]=filtbank(xe3*max(abs(CL)/dbmax),25641);
[Xt4]=filtbank(xe4*max(abs(CL)/dbmax),25641);
[Xt6]=filtbank(xe6*max(abs(CL)/dbmax),25641);
[Xt7]=filtbank(xe7*max(abs(CL)/dbmax),25641);
[Xt8]=filtbank(xe8*max(abs(CL)/dbmax),25641);
[Xt9]=filtbank(xe9*max(abs(CL)/dbmax),25641);

% Representacin de las componentes directa y transmitida en 1/3 de octava.
figure
subplot(5,2,1);bankdisp(Xd,F);title('componente directa')
subplot(5,2,2);bankdisp(Xt5,F);title('transmitida 5')
subplot(5,2,3);bankdisp(Xt1,F);title('transmitida 1')
subplot(5,2,4);bankdisp(Xt2,F);title('transmitida 2')
subplot(5,2,5);bankdisp(Xt3,F);title('transmitida 3')
subplot(5,2,6);bankdisp(Xt4,F);title('transmitida 4')
subplot(5,2,7);bankdisp(Xt6,F);title('transmitida 6')
subplot(5,2,8);bankdisp(Xt7,F);title('transmitida 7')
subplot(5,2,9);bankdisp(Xt8,F);title('transmitida 8')
subplot(5,2,10);bankdisp(Xt9,F);title('transmitida 9')

% Seal de salida.
Xd=Xd';Xt5=Xt5';Xt1=Xt1';Xt2=Xt2';Xt3=Xt3';Xt4=Xt4';Xt6=Xt6';Xt7=Xt7';
Xt8=Xt8';Xt9=Xt9';
X=[Xd,Xt5,Xt1,Xt2,Xt3,Xt4,Xt6,Xt7,Xt8,Xt9];