function[Xd,Xr]=reflexion(tad,tar,dbmax)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funcin que realiza todos los parmetros intermedios para obtener el
% RI que clasifique pantallas acsticas segn la norma CEN/TS 1793-6.
%
%  function[X]=reflexion(tad,tar,dbmax)
%
%     DATOS DE ENTRADA:
%          tad: Tamao de la ventana temporal de Adrienne para la
%               componente directa (ms).
%          tar: Tamao de la ventana temporal de Adrienne para la
%               componente directa y reflejada juntas (ms).
%          dbmax: Nivel mximo de seal obtenido (dB).
%
%     DATOS INTERMEDIOS:
%          Figuras 1 y 2. Respuestas impulsivas sobre ventana de Adrienne.
%          Figuras 3. Componentes directa y reflejadas en el tiempo.
%          Figuras 4. Componentes directas en frec.(1/3).
%          Figuras 5. Componentes reflejadas en frec.(1/3).
%
%     DATOS DE SALIDA:
%          Xd. Componentes directas en 1/3 de octava puestas en columnas 
%             (directa,90,50,60,etc).
%          Xr. Componentes directas en 1/3 de octava puestas en columnas 
%             (90,50,60,etc).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Eje de tiempos de la seal MLS, milisegundos a los que se reproduce
% cada muestra y duracin de la seal.
load ejex;ejex=ejex';

% Respuestas impulsionales medidas, en filas.
load CL;CL=dbmax/max(abs(CL))*CL;CL=abs(CL)';
load rimp90;rimp90=dbmax/max(abs(rimp90))*rimp90;rimp90=abs(rimp90)';
load rimp50;rimp50=dbmax/max(abs(rimp50))*rimp50;rimp50=abs(rimp50)';
load rimp60;rimp60=dbmax/max(abs(rimp60))*rimp60;rimp60=abs(rimp60)';
load rimp70;rimp70=dbmax/max(abs(rimp70))*rimp70;rimp70=abs(rimp70)';
load rimp80;rimp80=dbmax/max(abs(rimp80))*rimp80;rimp80=abs(rimp80)';
load rimp100;rimp100=dbmax/max(abs(rimp100))*rimp100;rimp100=abs(rimp100)';
load rimp110;rimp110=dbmax/max(abs(rimp110))*rimp110;rimp110=abs(rimp110)';
load rimp120;rimp120=dbmax/max(abs(rimp120))*rimp120;rimp120=abs(rimp120)';
load rimp130;rimp130=dbmax/max(abs(rimp130))*rimp130;rimp130=abs(rimp130)';

% Ventanas de Adrienne para la componente reflejada y directa.
[wr]= adrienne(ejex,tar);
[wd]= adrienne(ejex,tad);

% Enventanado de las seales.
[xeCL,weCL]=enventanado(CL,wd,ejex);
[xe90,we90]=enventanado(rimp90,wr,ejex);
[xe50,we50]=enventanado(rimp50,wr,ejex);
[xe60,we60]=enventanado(rimp60,wr,ejex);
[xe70,we70]=enventanado(rimp70,wr,ejex);
[xe80,we80]=enventanado(rimp80,wr,ejex);
[xe100,we100]=enventanado(rimp100,wr,ejex);
[xe110,we110]=enventanado(rimp110,wr,ejex);
[xe120,we120]=enventanado(rimp120,wr,ejex);
[xe130,we130]=enventanado(rimp130,wr,ejex);

% Representacin de la ventana de Adrienne sobre las seales para
% comprobar la largura de esta.
figure
subplot(3,2,1);plot(ejex,CL);title('Campo libre')
hold on;subplot(3,2,1);plot(ejex,weCL*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,2);plot(ejex,rimp90);title('90')
hold on;subplot(3,2,2);plot(ejex,we90*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,3);plot(ejex,rimp50);title('50')
hold on;subplot(3,2,3);plot(ejex,we50*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,4);plot(ejex,rimp60);title('60')
hold on;subplot(3,2,4);plot(ejex,we60*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,5);plot(ejex,rimp70);title('70')
hold on;subplot(3,2,5);plot(ejex,we70*20,'r--');xlabel('Tiempo(ms)');
figure
subplot(3,2,1);plot(ejex,rimp80);title('80')
hold on;subplot(3,2,1);plot(ejex,we80*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,2);plot(ejex,rimp100);title('100')
hold on;subplot(3,2,2);plot(ejex,we100*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,3);plot(ejex,rimp110);title('110')
hold on;subplot(3,2,3);plot(ejex,we110*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,4);plot(ejex,rimp120);title('120')
hold on;subplot(3,2,4);plot(ejex,we120*20,'r--');xlabel('Tiempo(ms)');
subplot(3,2,5);plot(ejex,rimp130);title('130')
hold on;subplot(3,2,5);plot(ejex,we130*20,'r--');xlabel('Tiempo(ms)');

% Enventanado de la componente directa en cada una de las seales medidas
% enventanadas para obtenerla y despus suprimir para obtener la reflejada.
[dir90,w90]=enventanado(xe90,wd,ejex);
[dir50,w50]=enventanado(xe50,wd,ejex);
[dir60,w60]=enventanado(xe60,wd,ejex);
[dir70,w70]=enventanado(xe70,wd,ejex);
[dir80,w80]=enventanado(xe80,wd,ejex);
[dir100,w100]=enventanado(xe100,wd,ejex);
[dir110,w110]=enventanado(xe110,wd,ejex);
[dir120,w120]=enventanado(xe120,wd,ejex);
[dir130,w130]=enventanado(xe130,wd,ejex);

% Inversa de la ventana de Adrienne para obtener todo lo que no sea la
% componente directa de la seal.
inv90=1-w90;inv50=1-w50;inv60=1-w60;inv70=1-w70;inv80=1-w80;
inv100=1-w100;inv110=1-w110;inv120=1-w120;inv130=1-w130;

%Seales reflejadas.
xr90=xe90.*inv90;xr50=xe50.*inv50;xr60=xe60.*inv60;xr70=xe70.*inv70;
xr80=xe80.*inv80;xr100=xe100.*inv100;xr110=xe110.*inv110;
xr120=xe120.*inv120;xr130=xe130.*inv130;

%Enventanado para obtener solo la reflexin de la pantalla.
[refl90]=enventanado(xr90,wd,ejex);
[refl50]=enventanado(xr50,wd,ejex);
[refl60]=enventanado(xr60,wd,ejex);
[refl70]=enventanado(xr70,wd,ejex);
[refl80]=enventanado(xr80,wd,ejex);
[refl100]=enventanado(xr100,wd,ejex);
[refl110]=enventanado(xr110,wd,ejex);
[refl120]=enventanado(xr120,wd,ejex);
[refl130]=enventanado(xr130,wd,ejex);

% Multiplicacin de la seal enventanada por el tiempo de medida para
% compensar atenuaciones.
dir=xeCL.*(ejex./1000);
refl90=refl90.*(ejex./1000);dir90=dir90.*(ejex./1000);
refl50=refl50.*(ejex./1000);dir50=dir50.*(ejex./1000);
refl60=refl60.*(ejex./1000);dir60=dir60.*(ejex./1000);
refl70=refl70.*(ejex./1000);dir70=dir70.*(ejex./1000);
refl80=refl80.*(ejex./1000);dir80=dir80.*(ejex./1000);
refl100=refl100.*(ejex./1000);dir100=dir100.*(ejex./1000);
refl110=refl110.*(ejex./1000);dir110=dir110.*(ejex./1000);
refl120=refl120.*(ejex./1000);dir120=dir120.*(ejex./1000);
refl130=refl130.*(ejex./1000);dir130=dir130.*(ejex./1000);

% Representacin de las componentes directas y reflejadas finales.
figure
subplot(5,2,1);plot(ejex,dir);title('componente directa')
subplot(5,2,2);plot(ejex,dir90);title('90')
hold on;plot(ejex,refl90,'g');
subplot(5,2,3);plot(ejex,dir50);title('50')
hold on;plot(ejex,refl50,'g');
subplot(5,2,4);plot(ejex,dir60.*ejex);title('60')
hold on;plot(ejex,refl60,'g');
subplot(5,2,5);plot(ejex,dir70.*ejex);title('70')
hold on;plot(ejex,refl70,'g');
subplot(5,2,6);plot(ejex,dir80.*ejex);title('80')
hold on;plot(ejex,refl80,'g');
subplot(5,2,7);plot(ejex,dir100.*ejex);title('100')
hold on;plot(ejex,refl100,'g');
subplot(5,2,8);plot(ejex,dir110.*ejex);title('110')
hold on;plot(ejex,refl110,'g');
subplot(5,2,9);plot(ejex,dir120.*ejex);title('120')
hold on;plot(ejex,refl120,'g');
subplot(5,2,10);plot(ejex,dir130.*ejex);title('130')
hold on;plot(ejex,refl130,'g');

% Espectro de potencia de cada una de las componentes.
[Xd,F]=filtbank(dir,25641);
[Xd90]=filtbank(dir90,25641);[Xr90]=filtbank(refl90,25641);
[Xd50]=filtbank(dir50,25641);[Xr50]=filtbank(refl50,25641);
[Xd60]=filtbank(dir60,25641);[Xr60]=filtbank(refl60,25641);
[Xd70]=filtbank(dir70,25641);[Xr70]=filtbank(refl70,25641);
[Xd80]=filtbank(dir80,25641);[Xr80]=filtbank(refl80,25641);
[Xd100]=filtbank(dir100,25641);[Xr100]=filtbank(refl100,25641);
[Xd110]=filtbank(dir110,25641);[Xr110]=filtbank(refl110,25641);
[Xd120]=filtbank(dir120,25641);[Xr120]=filtbank(refl120,25641);
[Xd130]=filtbank(dir130,25641);[Xr130]=filtbank(refl130,25641);

% Representacin de las componentes directas en 1/3 de octava.
figure
subplot(5,2,1);bankdisp(Xd,F);title('componente directa')
subplot(5,2,2);bankdisp(Xd90,F);title('90')
subplot(5,2,3);bankdisp(Xd50,F);title('50')
subplot(5,2,4);bankdisp(Xd60,F);title('60')
subplot(5,2,5);bankdisp(Xd70,F);title('70')
subplot(5,2,6);bankdisp(Xd80,F);title('80')
subplot(5,2,7);bankdisp(Xd100,F);title('100')
subplot(5,2,8);bankdisp(Xd110,F);title('110')
subplot(5,2,9);bankdisp(Xd120,F);title('120')
subplot(5,2,10);bankdisp(Xd130,F);title('130')

% Representacin de las componentes reflejadas en 1/3 de octava.
figure
subplot(5,2,2);bankdisp(Xr90,F);title('90')
subplot(5,2,3);bankdisp(Xr50,F);title('50')
subplot(5,2,4);bankdisp(Xr60,F);title('60')
subplot(5,2,5);bankdisp(Xr70,F);title('70')
subplot(5,2,6);bankdisp(Xr80,F);title('80')
subplot(5,2,7);bankdisp(Xr100,F);title('100')
subplot(5,2,8);bankdisp(Xr110,F);title('110')
subplot(5,2,9);bankdisp(Xr120,F);title('120')
subplot(5,2,10);bankdisp(Xr130,F);title('130')

%Seales de salida.
Xd=Xd';Xd90=Xd90';Xd50=Xd50';Xd60=Xd60';Xd70=Xd70';Xd80=Xd80';
Xd100=Xd100';Xd110=Xd110';Xd120=Xd120';Xd130=Xd130';
Xd=[Xd,Xd90,Xd50,Xd60,Xd70,Xd80,Xd100,Xd110,Xd120,Xd130];
Xr90=Xr90';Xr50=Xr50';Xr60=Xr60';Xr70=Xr70';Xr80=Xr80';
Xr100=Xr100';Xr110=Xr110';Xr120=Xr120';Xr130=Xr130';
Xr=[Xr90,Xr50,Xr60,Xr70,Xr80,Xr100,Xr110,Xr120,Xr130];